@@ -1,7 +1,7 @@
 import sys
 from typing import List, Union
 
-from je_auto_control.utils.exception.exception_tag import windows_import_error
+from je_auto_control.utils.exception.exception_tags import windows_import_error
 from je_auto_control.utils.exception.exceptions import AutoControlException
 
 if sys.platform not in ["win32", "cygwin", "msys"]:
